import _inheritsLoose from "@babel/runtime/helpers/inheritsLoose";
import _extends from "@babel/runtime/helpers/extends";

var _class, _class2, _class3, _class4;

import { Component, Fragment } from 'react';
import classNames from 'classnames';
import { observer, Title, Tip, globalContext, Editor, engineConfig } from '@alilc/lowcode-editor-core';
import { createIcon } from '@alilc/lowcode-utils';
import { IconArrowRight } from '../icons/arrow-right';
import { IconEyeClose } from '../icons/eye-close';
import { intl, intlNode } from '../locale';
import { IconEye } from '../icons/eye';
import { IconCond } from '../icons/cond';
import { IconLoop } from '../icons/loop';
import { IconRadioActive } from '../icons/radio-active';
import { IconRadio } from '../icons/radio';
import { IconLock, IconUnlock } from '../icons';

function emitOutlineEvent(type, treeNode, rest) {
  var _node$componentMeta, _node$componentMeta2;

  var editor = globalContext.get(Editor);
  var node = treeNode === null || treeNode === void 0 ? void 0 : treeNode.node;
  var npm = node === null || node === void 0 ? void 0 : (_node$componentMeta = node.componentMeta) === null || _node$componentMeta === void 0 ? void 0 : _node$componentMeta.npm;
  var selected = [npm === null || npm === void 0 ? void 0 : npm["package"], npm === null || npm === void 0 ? void 0 : npm.componentName].filter(function (item) {
    return !!item;
  }).join('-') || (node === null || node === void 0 ? void 0 : (_node$componentMeta2 = node.componentMeta) === null || _node$componentMeta2 === void 0 ? void 0 : _node$componentMeta2.componentName) || '';
  editor === null || editor === void 0 ? void 0 : editor.emit("outlinePane." + type, _extends({
    selected: selected
  }, rest));
}

var TreeTitle = observer(_class4 = /*#__PURE__*/function (_Component4) {
  _inheritsLoose(TreeTitle, _Component4);

  function TreeTitle() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _Component4.call.apply(_Component4, [this].concat(args)) || this;
    _this.state = {
      editing: false
    };

    _this.enableEdit = function () {
      _this.setState({
        editing: true
      });
    };

    _this.saveEdit = function (e) {
      var treeNode = _this.props.treeNode;
      var value = e.target.value || '';
      treeNode.setTitleLabel(value);
      emitOutlineEvent('rename', treeNode, {
        value: value
      });

      _this.cancelEdit();
    };

    _this.handleKeyUp = function (e) {
      if (e.keyCode === 13) {
        _this.saveEdit(e);
      }

      if (e.keyCode === 27) {
        _this.cancelEdit();
      }
    };

    _this.lastInput = void 0;

    _this.setCaret = function (input) {
      if (!input || _this.lastInput === input) {
        return;
      }

      input.focus();
      input.select(); // 光标定位最后一个
      // input.selectionStart = input.selectionEnd;
    };

    return _this;
  }

  var _proto4 = TreeTitle.prototype;

  _proto4.cancelEdit = function cancelEdit() {
    this.setState({
      editing: false
    });
    this.lastInput = undefined;
  };

  _proto4.render = function render() {
    var _this$props = this.props,
        treeNode = _this$props.treeNode,
        isModal = _this$props.isModal;
    var editing = this.state.editing;
    var isCNode = !treeNode.isRoot();
    var node = treeNode.node;
    var isNodeParent = node.isParental();
    var isContainer = node.isContainer();
    var style;

    if (isCNode) {
      var depth = treeNode.depth;
      var indent = depth * 12;
      style = {
        paddingLeft: indent + (isModal ? 12 : 0),
        marginLeft: -indent
      };
    }

    var _treeNode$filterReult = treeNode.filterReult,
        filterWorking = _treeNode$filterReult.filterWorking,
        matchSelf = _treeNode$filterReult.matchSelf,
        keywords = _treeNode$filterReult.keywords;
    return /*#__PURE__*/React.createElement("div", {
      className: classNames('tree-node-title', {
        editing: editing
      }),
      style: style,
      "data-id": treeNode.id,
      onClick: function onClick() {
        if (isModal) {
          if (node.getVisible()) {
            node.document.modalNodesManager.setInvisible(node);
          } else {
            node.document.modalNodesManager.setVisible(node);
          }

          return;
        }

        if (node.conditionGroup) {
          node.setConditionalVisible();
        }
      }
    }, isModal && node.getVisible() && /*#__PURE__*/React.createElement("div", {
      onClick: function onClick() {
        node.document.modalNodesManager.setInvisible(node);
      }
    }, /*#__PURE__*/React.createElement(IconRadioActive, {
      className: "tree-node-modal-radio-active"
    })), isModal && !node.getVisible() && /*#__PURE__*/React.createElement("div", {
      onClick: function onClick() {
        node.document.modalNodesManager.setVisible(node);
      }
    }, /*#__PURE__*/React.createElement(IconRadio, {
      className: "tree-node-modal-radio"
    })), isCNode && /*#__PURE__*/React.createElement(ExpandBtn, {
      treeNode: treeNode
    }), /*#__PURE__*/React.createElement("div", {
      className: "tree-node-icon"
    }, createIcon(treeNode.icon)), /*#__PURE__*/React.createElement("div", {
      className: "tree-node-title-label",
      onDoubleClick: isNodeParent ? this.enableEdit : undefined
    }, editing ? /*#__PURE__*/React.createElement("input", {
      className: "tree-node-title-input",
      defaultValue: treeNode.titleLabel,
      onBlur: this.saveEdit,
      ref: this.setCaret,
      onKeyUp: this.handleKeyUp
    }) : /*#__PURE__*/React.createElement(Fragment, null, /*#__PURE__*/React.createElement(Title, {
      title: treeNode.title,
      match: filterWorking && matchSelf,
      keywords: keywords
    }), node.slotFor && /*#__PURE__*/React.createElement("a", {
      className: "tree-node-tag slot"
    }, /*#__PURE__*/React.createElement(Tip, null, intlNode('Slot for {prop}', {
      prop: node.slotFor.key
    }))), node.hasLoop() && /*#__PURE__*/React.createElement("a", {
      className: "tree-node-tag loop"
    }, /*#__PURE__*/React.createElement(IconLoop, null), /*#__PURE__*/React.createElement(Tip, null, intlNode('Loop'))), node.hasCondition() && !node.conditionGroup && /*#__PURE__*/React.createElement("a", {
      className: "tree-node-tag cond"
    }, /*#__PURE__*/React.createElement(IconCond, null), /*#__PURE__*/React.createElement(Tip, null, intlNode('Conditional'))))), isCNode && isNodeParent && !isModal && /*#__PURE__*/React.createElement(HideBtn, {
      treeNode: treeNode
    }), engineConfig.get('enableCanvasLock', false) && isContainer && isCNode && isNodeParent && /*#__PURE__*/React.createElement(LockBtn, {
      treeNode: treeNode
    }));
  };

  return TreeTitle;
}(Component)) || _class4;

export { TreeTitle as default };

var LockBtn = observer(_class = /*#__PURE__*/function (_Component) {
  _inheritsLoose(LockBtn, _Component);

  function LockBtn() {
    return _Component.apply(this, arguments) || this;
  }

  var _proto = LockBtn.prototype;

  _proto.render = function render() {
    var treeNode = this.props.treeNode;
    return /*#__PURE__*/React.createElement("div", {
      className: "tree-node-lock-btn",
      onClick: function onClick(e) {
        e.stopPropagation();
        treeNode.setLocked(!treeNode.locked);
      }
    }, treeNode.locked ? /*#__PURE__*/React.createElement(IconUnlock, null) : /*#__PURE__*/React.createElement(IconLock, null), /*#__PURE__*/React.createElement(Tip, null, treeNode.locked ? intl('Unlock') : intl('Lock')));
  };

  return LockBtn;
}(Component)) || _class;

var HideBtn = observer(_class2 = /*#__PURE__*/function (_Component2) {
  _inheritsLoose(HideBtn, _Component2);

  function HideBtn() {
    return _Component2.apply(this, arguments) || this;
  }

  var _proto2 = HideBtn.prototype;

  _proto2.render = function render() {
    var treeNode = this.props.treeNode;
    return /*#__PURE__*/React.createElement("div", {
      className: "tree-node-hide-btn",
      onClick: function onClick(e) {
        e.stopPropagation();
        emitOutlineEvent(treeNode.hidden ? 'show' : 'hide', treeNode);
        treeNode.setHidden(!treeNode.hidden);
      }
    }, treeNode.hidden ? /*#__PURE__*/React.createElement(IconEye, null) : /*#__PURE__*/React.createElement(IconEyeClose, null), /*#__PURE__*/React.createElement(Tip, null, treeNode.hidden ? intl('Show') : intl('Hide')));
  };

  return HideBtn;
}(Component)) || _class2;

var ExpandBtn = observer(_class3 = /*#__PURE__*/function (_Component3) {
  _inheritsLoose(ExpandBtn, _Component3);

  function ExpandBtn() {
    return _Component3.apply(this, arguments) || this;
  }

  var _proto3 = ExpandBtn.prototype;

  _proto3.render = function render() {
    var treeNode = this.props.treeNode;

    if (!treeNode.expandable) {
      return /*#__PURE__*/React.createElement("i", {
        className: "tree-node-expand-placeholder"
      });
    }

    return /*#__PURE__*/React.createElement("div", {
      className: "tree-node-expand-btn",
      onClick: function onClick(e) {
        if (treeNode.expanded) {
          e.stopPropagation();
        }

        emitOutlineEvent(treeNode.expanded ? 'collapse' : 'expand', treeNode);
        treeNode.setExpanded(!treeNode.expanded);
      }
    }, /*#__PURE__*/React.createElement(IconArrowRight, {
      size: "small"
    }));
  };

  return ExpandBtn;
}(Component)) || _class3;
/*
interface Point {
  clientX: number;
  clientY: number;
}

function setCaret(point: Point) {
  debugger;
  const range = getRangeFromPoint(point);
  if (range) {
    selectRange(range);
    setTimeout(() => selectRange(range), 1);
  }
}

function getRangeFromPoint(point: Point): Range | undefined {
  const x = point.clientX;
  const y = point.clientY;
  let range;
  let pos: CaretPosition | null = null;
  if (document.caretRangeFromPoint) {
    range = document.caretRangeFromPoint(x, y);
  } else if ((pos = document.caretPositionFromPoint(x, y))) {
    range = document.createRange();
    range.setStart(pos.offsetNode, pos.offset);
    range.collapse(true);

  }
  return range;
}

function selectRange(range: Range) {
  const selection = document.getSelection();
  if (selection) {
    selection.removeAllRanges();
    selection.addRange(range);
  }
}

function setCaretAfter(elem) {
  const range = document.createRange();
  const node = elem.lastChild;
  if (!node) return;
  range.setStartAfter(node);
  range.setEndAfter(node);
  selectRange(range);
}
*/