import { TitleContent } from '@alilc/lowcode-types';
import { Node, DocumentModel, LocationChildrenDetail, Designer } from '@alilc/lowcode-designer';
import { Tree } from './tree';
/**
 * 大纲树过滤结果
 */
export interface FilterResult {
    filterWorking: boolean;
    matchChild: boolean;
    matchSelf: boolean;
    keywords: string;
}
export default class TreeNode {
    get id(): string;
    /**
     * 是否可以展开
     */
    get expandable(): boolean;
    /**
     * 插入"线"位置信息
     */
    get dropDetail(): LocationChildrenDetail | undefined | null;
    get depth(): number;
    isRoot(includeOriginalRoot?: boolean): boolean;
    /**
     * 是否是响应投放区
     */
    isResponseDropping(): boolean;
    isFocusingNode(): boolean;
    /**
     * 默认为折叠状态
     * 在初始化根节点时，设置为展开状态
     */
    private _expanded;
    get expanded(): boolean;
    setExpanded(value: boolean): void;
    get detecting(): boolean;
    get hidden(): boolean;
    setHidden(flag: boolean): void;
    get locked(): boolean;
    setLocked(flag: boolean): void;
    get selected(): boolean;
    get title(): TitleContent;
    get titleLabel(): string;
    setTitleLabel(label: string): void;
    get icon(): any;
    get parent(): TreeNode | null;
    get slots(): TreeNode[];
    get children(): TreeNode[] | null;
    /**
     * 是否是容器，允许子节点拖入
     */
    isContainer(): boolean;
    /**
     * 判断是否有"插槽"
     */
    hasSlots(): boolean;
    hasChildren(): boolean;
    select(isMulti: boolean): void;
    /**
     * 展开节点，支持依次展开父节点
     */
    expand(tryExpandParents?: boolean): void;
    expandParents(): void;
    readonly designer: Designer;
    readonly document: DocumentModel;
    private _node;
    get node(): Node<import("@alilc/lowcode-types").NodeSchema>;
    readonly tree: Tree;
    constructor(tree: Tree, node: Node);
    setNode(node: Node): void;
    private _filterResult;
    get filterReult(): FilterResult;
    setFilterReult(val: FilterResult): void;
}
