"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports["default"] = void 0;

var _inheritsLoose2 = _interopRequireDefault(require("@babel/runtime/helpers/inheritsLoose"));

var _react = require("react");

var _lowcodeEditorCore = require("@alilc/lowcode-editor-core");

var _lowcodeDesigner = require("@alilc/lowcode-designer");

var _lowcodeUtils = require("@alilc/lowcode-utils");

var _rootTreeNode = _interopRequireDefault(require("./root-tree-node"));

var _class;

function getTreeNodeIdByEvent(e, stop) {
  var target = e.target;

  if (!target || !stop.contains(target)) {
    return null;
  }

  target = target.closest('[data-id]');

  if (!target || !stop.contains(target)) {
    return null;
  }

  return target.dataset.id || null;
}

var TreeView = (0, _lowcodeEditorCore.observer)(_class = /*#__PURE__*/function (_Component) {
  (0, _inheritsLoose2["default"])(TreeView, _Component);

  function TreeView() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _Component.call.apply(_Component, [this].concat(args)) || this;
    _this.shell = null;

    _this.onClick = function (e) {
      if (_this.ignoreUpSelected) {
        _this.boostEvent = undefined;
        return;
      }

      if (_this.boostEvent && (0, _lowcodeDesigner.isShaken)(_this.boostEvent, e.nativeEvent)) {
        _this.boostEvent = undefined;
        return;
      }

      _this.boostEvent = undefined;

      var treeNode = _this.getTreeNodeFromEvent(e);

      if (!treeNode) {
        return;
      }

      var node = treeNode.node;

      if (!(0, _lowcodeUtils.canClickNode)(node, e)) {
        return;
      }

      var designer = treeNode.designer;
      var doc = node.document;
      var selection = doc.selection,
          focusNode = doc.focusNode;
      var id = node.id;
      var isMulti = e.metaKey || e.ctrlKey || e.shiftKey;
      designer.activeTracker.track(node);

      if (isMulti && !node.contains(focusNode) && selection.has(id)) {
        if (!(0, _lowcodeUtils.isFormEvent)(e.nativeEvent)) {
          selection.remove(id);
        }
      } else {
        var _designer$currentSele, _designer$currentSele2, _selectedNode$compone, _selectedNode$compone2;

        selection.select(id);

        var editor = _lowcodeEditorCore.globalContext.get(_lowcodeEditorCore.Editor);

        var selectedNode = (_designer$currentSele = designer.currentSelection) === null || _designer$currentSele === void 0 ? void 0 : (_designer$currentSele2 = _designer$currentSele.getNodes()) === null || _designer$currentSele2 === void 0 ? void 0 : _designer$currentSele2[0];
        var npm = selectedNode === null || selectedNode === void 0 ? void 0 : (_selectedNode$compone = selectedNode.componentMeta) === null || _selectedNode$compone === void 0 ? void 0 : _selectedNode$compone.npm;
        var selected = [npm === null || npm === void 0 ? void 0 : npm["package"], npm === null || npm === void 0 ? void 0 : npm.componentName].filter(function (item) {
          return !!item;
        }).join('-') || (selectedNode === null || selectedNode === void 0 ? void 0 : (_selectedNode$compone2 = selectedNode.componentMeta) === null || _selectedNode$compone2 === void 0 ? void 0 : _selectedNode$compone2.componentName) || '';
        editor === null || editor === void 0 ? void 0 : editor.emit('outlinePane.select', {
          selected: selected
        });
      }
    };

    _this.onMouseOver = function (e) {
      _this.hover(e);
    };

    _this.ignoreUpSelected = false;
    _this.boostEvent = void 0;

    _this.onMouseDown = function (e) {
      if ((0, _lowcodeUtils.isFormEvent)(e.nativeEvent)) {
        return;
      }

      var treeNode = _this.getTreeNodeFromEvent(e);

      if (!treeNode) {
        return;
      }

      var node = treeNode.node;

      if (!(0, _lowcodeUtils.canClickNode)(node, e)) {
        return;
      }

      var designer = treeNode.designer;
      var doc = node.document;
      var selection = doc.selection,
          focusNode = doc.focusNode; // TODO: shift selection

      var isMulti = e.metaKey || e.ctrlKey || e.shiftKey;
      var isLeftButton = e.button === 0;

      if (isLeftButton && !node.contains(focusNode)) {
        var nodes = [node];
        _this.ignoreUpSelected = false;

        if (isMulti) {
          // multi select mode, directily add
          if (!selection.has(node.id)) {
            designer.activeTracker.track(node);
            selection.add(node.id);
            _this.ignoreUpSelected = true;
          } // todo: remove rootNodes id


          selection.remove(focusNode.id); // 获得顶层 nodes

          nodes = selection.getTopNodes();
        } else if (selection.has(node.id)) {
          nodes = selection.getTopNodes();
        }

        _this.boostEvent = e.nativeEvent;
        designer.dragon.boost({
          type: _lowcodeDesigner.DragObjectType.Node,
          nodes: nodes
        }, _this.boostEvent);
      }
    };

    _this.onMouseLeave = function () {
      var tree = _this.props.tree;
      var doc = tree.document;
      doc.designer.detecting.leave(doc);
    };

    return _this;
  }

  var _proto = TreeView.prototype;

  _proto.hover = function hover(e) {
    var _this$getTreeNodeFrom;

    var tree = this.props.tree;
    var doc = tree.document;
    var detecting = doc.designer.detecting;

    if (!detecting.enable) {
      return;
    }

    var node = (_this$getTreeNodeFrom = this.getTreeNodeFromEvent(e)) === null || _this$getTreeNodeFrom === void 0 ? void 0 : _this$getTreeNodeFrom.node;
    detecting.capture(node || null);
  };

  _proto.getTreeNodeFromEvent = function getTreeNodeFromEvent(e) {
    if (!this.shell) {
      return;
    }

    var id = getTreeNodeIdByEvent(e, this.shell);

    if (!id) {
      return;
    }

    var tree = this.props.tree;
    return tree.getTreeNodeById(id);
  };

  _proto.render = function render() {
    var _this2 = this;

    var tree = this.props.tree;
    var root = tree.root;

    if (!root) {
      return null;
    }

    return /*#__PURE__*/React.createElement("div", {
      className: "lc-outline-tree",
      ref: function ref(shell) {
        _this2.shell = shell;
      },
      onMouseDownCapture: this.onMouseDown,
      onMouseOver: this.onMouseOver,
      onClick: this.onClick,
      onMouseLeave: this.onMouseLeave
    }, /*#__PURE__*/React.createElement(_rootTreeNode["default"], {
      key: root.id,
      treeNode: root
    }));
  };

  return TreeView;
}(_react.Component)) || _class;

exports["default"] = TreeView;